@@ -2,14 +2,15 @@ import json
 import base64
 import requests
 import threading
-
+import secmail
+from bs4 import BeautifulSoup
 from uuid import UUID
 from os import urandom
 from time import timezone, sleep
 from typing import BinaryIO
 from binascii import hexlify
 from time import time as timestamp
-from locale import getdefaultlocale as locale
+from locale import getdefaultlocale as local
 
 from .lib.util import exceptions, headers, device, objects, helpers
 from .socket import Callbacks, SocketHandler
@@ -35,9 +36,11 @@ class Client(Callbacks, SocketHandler):
         self.json = None
         self.sid = None
         self.userId = None
+        self.web_headers = headers.Headers().web_headers
+        self.reg_headers=headers.Headers().reg_headers
         self.account: objects.UserProfile = objects.UserProfile(None)
         self.profile: objects.UserProfile = objects.UserProfile(None)
-        self.check_device(self.device_id)
+        #self.check_device(self.device_id)
         #rint(self.device_id)
         
     def parse_headers(self, data = None):
@@ -639,6 +642,106 @@ class Client(Callbacks, SocketHandler):
         if response.status_code != 200: return exceptions.CheckException(json.loads(response.text))
         else: return response.status_code
 
+    def gen_email(self):
+        mail = secmail.SecMail()
+        email = mail.generate_email()
+        return email
+    
+    
+    
+    def get_message(self,email):
+    	shown=0
+    	while shown==0:
+    	       try:
+    	       	sleep(3)
+    	       	f=email
+    	       	mail = secmail.SecMail()
+    	       	inbox = mail.get_messages(f)
+    	       	print('done')
+    	       	for Id in inbox.id:
+    	       		msg = mail.read_message(email=f, id=Id).htmlBody
+    	       		bs = BeautifulSoup(msg, 'html.parser')
+    	       		images = bs.find_all('a')[0]
+    	       		url = (images['href']+'\n')
+    	       		if url is not None:
+    	       		  print('Vrification Url\n')
+    	       		  print(url)
+    	       		  #webbrowser.open(url)
+    	       		  shown=1
+    	       except:
+    	       	shown=0
+    	       	pass
+    	       	return shown
+
+    def check(self,email : str):
+      data=json.dumps({'email': email})
+      req=requests.post("https://aminoapps.com/api/register-check",data=data,headers=self.reg_headers)
+      if req.status_code != 200 : raise TypeError(req.text)
+      return json.loads(req.text)
+      
+    def check_code(self,email : str,code : str):
+        data=json.dumps({
+        'validationContext':{'data': {'code': code},
+        'identity': email,
+        'type': 1,
+        'verifyInfoKey': None}})
+        req=requests.post("https://aminoapps.com/api/auth/check-security-validation",data=data,headers=self.reg_headers)
+        if req.status_code != 200 : raise TypeError(req.text)
+        return json.loads(req.text)
+        
+    def register_check(self,email : str,password : str):
+      data=json.dumps({
+      'email': email,
+      'phoneNumber': "",
+      'secret': "hhhhhh"
+      })
+      req=requests.post("https://aminoapps.com/api/register-check",data=data,headers=self.reg_headers)
+      if req.status_code != 200 : raise TypeError(req.text)
+      return json.loads(req.text)
+    
+    def register_g(self,email : str, password : str,nickname : str,code : str):
+        data=({
+        'email': email,
+        'nickname': nickname,
+        'phoneNumber': "",
+        'secret2': password,
+        'validationContext': {
+            'data': {'code': code},
+            'code': code,
+            'identity': email,
+            'type': 1,
+            '__original':{
+                'data': {'code': code},
+                'code': code,
+                'identity': email,
+                'type' : 1,
+                '__response': {}
+        }}}) ; 
+        req=requests.post("https://aminoapps.com/api/register",json=data,headers=self.web_headers)
+        #print(req.text)
+        try:
+            if req.json()["result"]['api:message'] != "OK":
+                print(req.text)
+        except:
+            print(req.text)
+        print("Account Created")
+    
+    def verify_code(self,email):
+        #while True:
+        imgs=self.get_message(email)
+        verifycode=input("Code : ")
+        return verifycode
+
+
+    def register_new(self, nickname, password):
+    	email=self.gen_email()
+    	print(email)
+    	self.request_verify_code(email = email)
+    	print('Verification Code Sent')
+    	vcode=self.verify_code(email)
+    	self.register_g(email = email,password = password,nickname = nickname,code = vcode)
+    	return email
+
     def leave_chat(self, chatId: str):
         """
         Leave an Chat.
